<?php

namespace Drupal\sendethic;

/**
 * Represents a SendEthic Segment.
 */
class SendEthicSegment {

  /**
   * Segment ID.
   */
  protected ?int $id;

  /**
   * Segment Name.
   */
  protected ?string $name;

  /**
   * Segment Description.
   */
  protected ?string $description;

  /**
   * Segment Details.
   */
  protected ?string $details;

  /**
   * Segment Mode (union/intersection).
   */
  protected ?string $mode;

  /**
   * Constructs a new Segment.
   *
   * @param int $id
   *   Segment ID.
   * @param string $name
   *   Segment Name.
   * @param string|null $description
   *   Segment Description.
   * @param string|null $details
   *   Segment Details.
   * @param string|null $mode
   *   Segment Mode.
   */
  public function __construct(int $id, string $name, ?string $description = NULL, ?string $details = NULL, ?string $mode = NULL) {
    $this->id = $id;
    $this->name = $name;
    $this->description = $description;
    $this->details = $details;
    $this->mode = $mode;
  }

  /**
   * Return Segment ID.
   */
  public function getId(): ?int {
    return $this->id;
  }

  /**
   * Return Segment Name.
   */
  public function getName(): ?string {
    return $this->name;
  }

  /**
   * Return Segment Description.
   */
  public function getDescription(): ?string {
    return $this->description;
  }

  /**
   * Return Segment Details.
   */
  public function getDetails(): ?string {
    return $this->details;
  }

  /**
   * Return Segment Mode.
   */
  public function getMode(): ?string {
    return $this->mode;
  }

}
